Cond

Struct Cond 

pub struct Cond<Inner> {
    pub cond: bool,
    pub inner: Inner,
}
Combinator that checks if cond is true and then delegates to the inner combinator.

Fields

cond: bool

The condition to check before parsing or serializing.

inner: Inner

The combinator to delegate to if cond is true.