pub struct Cond<Inner> {
pub cond: bool,
pub inner: Inner,
}Expand description
Combinator that checks if cond is true and then delegates to the inner combinator.
Fields
cond: boolThe condition to check before parsing or serializing.
inner: InnerThe combinator to delegate to if cond is true.